==> g-cli-search-0.0.1.tgz: package/README.md <==
g-cli-search
============

Guilherme CLI Search plugin.

[![oclif](https://img.shields.io/badge/cli-oclif-brightgreen.svg)](https://oclif.io)
[![Version](https://img.shields.io/npm/v/g-cli-search.svg)](https://npmjs.org/package/g-cli-search)
[![CircleCI](https://circleci.com/gh/guilhermeiobbi/g-cli-search/tree/master.svg?style=shield)](https://circleci.com/gh/guilhermeiobbi/g-cli-search/tree/master)
[![Codecov](https://codecov.io/gh/guilhermeiobbi/g-cli-search/branch/master/graph/badge.svg)](https://codecov.io/gh/guilhermeiobbi/g-cli-search)
[![Downloads/week](https://img.shields.io/npm/dw/g-cli-search.svg)](https://npmjs.org/package/g-cli-search)
[![License](https://img.shields.io/npm/l/g-cli-search.svg)](https://github.com/guilhermeiobbi/g-cli-search/blob/master/package.json)

<!-- toc -->
* [Usage](#usage)
* [Commands](#commands)
<!-- tocstop -->
# Usage
<!-- usage -->
```sh-session
$ npm install -g @_giobbi/g-cli-search
$ oclif-example COMMAND
running command...
$ oclif-example (-v|--version|version)
@_giobbi/g-cli-search/0.0.1 linux-x64 node-v11.2.0
$ oclif-example --help [COMMAND]
USAGE
  $ oclif-example COMMAND
...
```
<!-- usagestop -->
# Commands
<!-- commands -->
* [`oclif-example search`](#oclif-example-search)

## `oclif-example search`

describe the command here

```
USAGE
  $ oclif-example search

OPTIONS
  -h, --help       show CLI help
  -n, --name=name  name to print

EXAMPLE
  $ oclif-example hello
  searching for <user_name>...
```

_See code: [src/commands/search.ts](https://github.com/guilhermeiobbi/g-cli-search/blob/v0.0.1/src/commands/search.ts)_
<!-- commandsstop -->

==> g-cli-search-0.0.3.tgz: package/README.md <==
g-cli-search
============

Guilherme CLI Search

[![oclif](https://img.shields.io/badge/cli-oclif-brightgreen.svg)](https://oclif.io)
[![Version](https://img.shields.io/npm/v/g-cli-search.svg)](https://npmjs.org/package/g-cli-search)
[![CircleCI](https://circleci.com/gh/guilhermeiobbi/g-cli-search/tree/master.svg?style=shield)](https://circleci.com/gh/guilhermeiobbi/g-cli-search/tree/master)
[![Codecov](https://codecov.io/gh/guilhermeiobbi/g-cli-search/branch/master/graph/badge.svg)](https://codecov.io/gh/guilhermeiobbi/g-cli-search)
[![Downloads/week](https://img.shields.io/npm/dw/g-cli-search.svg)](https://npmjs.org/package/g-cli-search)
[![License](https://img.shields.io/npm/l/g-cli-search.svg)](https://github.com/guilhermeiobbi/g-cli-search/blob/master/package.json)

<!-- toc -->
* [Usage](#usage)
* [Commands](#commands)
<!-- tocstop -->
# Usage
<!-- usage -->
```sh-session
$ npm install -g g-cli-search
$ oclif-example COMMAND
running command...
$ oclif-example (-v|--version|version)
g-cli-search/0.0.3 linux-x64 node-v11.2.0
$ oclif-example --help [COMMAND]
USAGE
  $ oclif-example COMMAND
...
```
<!-- usagestop -->
# Commands
<!-- commands -->
* [`oclif-example search`](#oclif-example-search)

## `oclif-example search`

Searches a poll

```
USAGE
  $ oclif-example search

OPTIONS
  -n, --number=number  poll number

DESCRIPTION
  ...
  Extra documentation goes here
```

_See code: [src/commands/search.js](https://github.com/guilhermeiobbi/g-cli-search/blob/v0.0.3/src/commands/search.js)_
<!-- commandsstop -->
